@@ -64,13 +64,6 @@ class EventsQueue(Generic[Event]):
         Sweeps plane and emits processed segments' events.
         """
 
-    def _orientation(self,
-                     vertex: Point,
-                     first_ray_point: Point,
-                     second_ray_point: Point) -> Orientation:
-        return self.context.angle_orientation(vertex, first_ray_point,
-                                              second_ray_point)
-
     def _segments_intersection(self,
                                first_start: Point,
                                first_end: Point,
@@ -79,8 +72,11 @@ class EventsQueue(Generic[Event]):
         return self.context.segments_intersection(first_start, first_end,
                                                   second_start, second_end)
 
-    def _segments_relation(self, first_start, first_end, second_start,
-                           second_end):
+    def _segments_relation(self,
+                           first_start: Point,
+                           first_end: Point,
+                           second_start: Point,
+                           second_end: Point) -> SegmentsRelation:
         result = self.context.segments_relation(first_start, first_end,
                                                 second_start, second_end)
         return (SegmentsRelation.DISJOINT if result is Relation.DISJOINT
@@ -111,13 +107,12 @@ class CompoundEventsQueue(EventsQueue[CompoundEvent]):
             self._queue.push(end_event)
 
     def divide_segment(self, event: CompoundEvent, break_point: Point) -> None:
-        left_event = self.event_cls(True, break_point, event.complement,
-                                    event.from_test, event.complement.relation,
-                                    event.interior_to_left)
-        right_event = self.event_cls(False, break_point, event,
-                                     event.from_test, event.relation,
-                                     event.interior_to_left)
-        event.complement.complement, event.complement = left_event, right_event
+        left_event = event.complement.complement = self.event_cls(
+                True, break_point, event.complement, event.from_test,
+                event.complement.relation, event.interior_to_left)
+        right_event = event.complement = self.event_cls(
+                False, break_point, event, event.from_test, event.relation,
+                event.interior_to_left)
         self._queue.push(left_event)
         self._queue.push(right_event)
 
@@ -232,18 +227,15 @@ class CompoundEventsQueue(EventsQueue[CompoundEvent]):
             point = self._segments_intersection(below_segment_start,
                                                 below_segment_end,
                                                 segment_start, segment_end)
-            if (event.start != below_event.start
-                    and event.end != below_event.end):
-                # segments do not intersect at endpoints
-                if point != below_event.start and point != below_event.end:
-                    self.divide_segment(below_event, point)
-                if point != event.start and point != event.end:
-                    self.divide_segment(event, point)
+            if point != below_event.start and point != below_event.end:
+                self.divide_segment(below_event, point)
+            if point != event.start and point != event.end:
+                self.divide_segment(event, point)
             if event.from_test is not below_event.from_test:
                 event.set_both_relations(max(event.relation,
                                              relation))
-                below_event.set_both_relations(
-                        max(below_event.relation, relation))
+                below_event.set_both_relations(max(below_event.relation,
+                                                   relation))
         return False
 
     @staticmethod
@@ -274,11 +266,11 @@ class LinearEventsQueue(EventsQueue[LinearEvent]):
             self._queue.push(end_event)
 
     def divide_segment(self, event: Event, break_point: Point) -> None:
-        left_event = self.event_cls(True, break_point, event.complement,
-                                    event.from_test, event.complement.relation)
-        right_event = self.event_cls(False, break_point, event,
-                                     event.from_test, event.relation)
-        event.complement.complement, event.complement = left_event, right_event
+        left_event = event.complement.complement = self.event_cls(
+                True, break_point, event.complement, event.from_test,
+                event.complement.relation)
+        right_event = event.complement = self.event_cls(
+                False, break_point, event, event.from_test, event.relation)
         self._queue.push(left_event)
         self._queue.push(right_event)
 
@@ -320,16 +312,16 @@ class LinearEventsQueue(EventsQueue[LinearEvent]):
                                               key=partial(point_event_cosine,
                                                           base_end))
                     largest_angle_end = largest_angle_event.end
-                    base_orientation = self._orientation(start, base_end,
-                                                         largest_angle_end)
-                    if all_equal(self._point_in_angle(other_event.end,
-                                                      base_end, start,
-                                                      largest_angle_end,
-                                                      base_orientation)
-                                 for other_event in from_other_events):
-                        relation = SegmentsRelation.TOUCH
-                    else:
-                        relation = SegmentsRelation.CROSS
+                    base_orientation = self.context.angle_orientation(
+                            start, base_end, largest_angle_end)
+                    relation = (
+                        SegmentsRelation.TOUCH
+                        if all_equal(self._point_in_angle(other_event.end,
+                                                          base_end, start,
+                                                          largest_angle_end,
+                                                          base_orientation)
+                                     for other_event in from_other_events)
+                        else SegmentsRelation.CROSS)
                 else:
                     relation = SegmentsRelation.TOUCH
                 for event in same_start_events:
@@ -356,8 +348,8 @@ class LinearEventsQueue(EventsQueue[LinearEvent]):
             prev_from_same_events, prev_from_other_events = (from_same_events,
                                                              from_other_events)
 
-    def detect_intersection(self, below_event: LinearEvent,
-                            event: LinearEvent) -> None:
+    def detect_intersection(self, below_event: LinearEvent, event: LinearEvent
+                            ) -> None:
         """
         Populates events queue with intersection events.
         """
@@ -421,13 +413,10 @@ class LinearEventsQueue(EventsQueue[LinearEvent]):
             point = self._segments_intersection(below_segment_start,
                                                 below_segment_end,
                                                 segment_start, segment_end)
-            if (event.start != below_event.start
-                    and event.end != below_event.end):
-                # segments do not intersect at endpoints
-                if point != below_event.start and point != below_event.end:
-                    self.divide_segment(below_event, point)
-                if point != event.start and point != event.end:
-                    self.divide_segment(event, point)
+            if point != below_event.start and point != below_event.end:
+                self.divide_segment(below_event, point)
+            if point != event.start and point != event.end:
+                self.divide_segment(event, point)
             if event.from_test is not below_event.from_test:
                 event.set_both_relations(max(event.relation, relation))
                 below_event.set_both_relations(max(below_event.relation,
@@ -436,17 +425,18 @@ class LinearEventsQueue(EventsQueue[LinearEvent]):
     def _to_point_event_cosine(self, point: Point, event: Event) -> Coordinate:
         return (self.context.dot_product(event.start, point, event.start,
                                          event.end)
-                / _points_distance(event.start, event.end))
+                / math.sqrt(self.context.points_squared_distance(event.start,
+                                                                 event.end)))
 
     def _point_in_angle(self, point: Point,
                         first_ray_point: Point,
                         vertex: Point,
                         second_ray_point: Point,
                         angle_orientation: Orientation) -> bool:
-        first_half_orientation = self._orientation(vertex, first_ray_point,
-                                                   point)
-        second_half_orientation = self._orientation(second_ray_point, vertex,
-                                                    point)
+        first_half_orientation = self.context.angle_orientation(
+                vertex, first_ray_point, point)
+        second_half_orientation = self.context.angle_orientation(
+                second_ray_point, vertex, point)
         return (second_half_orientation is angle_orientation
                 if first_half_orientation is Orientation.COLLINEAR
                 else (first_half_orientation is angle_orientation
@@ -493,7 +483,3 @@ class EventsQueueKey:
                           is (Orientation.COUNTERCLOCKWISE
                               if event.is_left_endpoint
                               else Orientation.CLOCKWISE)))
-
-
-def _points_distance(start: Point, end: Point) -> Coordinate:
-    return math.hypot(end.x - start.x, end.y - start.y)
