@@ -27,24 +27,24 @@ from .processing import (process_compound_queue,
 from .region import to_oriented_segments as region_to_oriented_segments
 
 
-def relate_point(multipolygon: Multipolygon, point: Point,
-                 *,
+def relate_point(multipolygon: Multipolygon,
+                 point: Point,
                  context: Context) -> Relation:
     for polygon in multipolygon.polygons:
         relation_with_polygon = relate_point_to_polygon(polygon, point,
-                                                        context=context)
+                                                        context)
         if relation_with_polygon is not Relation.DISJOINT:
             return relation_with_polygon
     return Relation.DISJOINT
 
 
-def relate_segment(multipolygon: Multipolygon, segment: Segment,
-                   *,
+def relate_segment(multipolygon: Multipolygon,
+                   segment: Segment,
                    context: Context) -> Relation:
     do_not_touch = True
     for polygon in multipolygon.polygons:
         relation_with_polygon = relate_segment_to_polygon(polygon, segment,
-                                                          context=context)
+                                                          context)
         if relation_with_polygon in (Relation.CROSS,
                                      Relation.COMPONENT,
                                      Relation.ENCLOSED,
@@ -59,16 +59,13 @@ def relate_segment(multipolygon: Multipolygon, segment: Segment,
 
 def relate_multisegment(multipolygon: Multipolygon,
                         multisegment: Multisegment,
-                        *,
                         context: Context) -> Relation:
     if not (multisegment.segments and multipolygon.polygons):
         return Relation.DISJOINT
-    multisegment_bounding_box = box.from_multisegment(multisegment,
-                                                      context=context)
+    multisegment_bounding_box = box.from_multisegment(multisegment, context)
     disjoint, multipolygon_max_x, events_queue = True, None, None
     for polygon in multipolygon.polygons:
-        polygon_bounding_box = box.from_polygon(polygon,
-                                                context=context)
+        polygon_bounding_box = box.from_polygon(polygon, context)
         if not box.disjoint_with(polygon_bounding_box,
                                  multisegment_bounding_box):
             if disjoint:
@@ -80,10 +77,9 @@ def relate_multisegment(multipolygon: Multipolygon,
             else:
                 multipolygon_max_x = max(multipolygon_max_x,
                                          polygon_bounding_box.max_x)
-            events_queue.register(
-                    polygon_to_oriented_segments(polygon,
-                                                 context=context),
-                    from_test=False)
+            events_queue.register(polygon_to_oriented_segments(polygon,
+                                                               context),
+                                  from_test=False)
     if disjoint:
         return Relation.DISJOINT
     return process_linear_compound_queue(events_queue,
@@ -91,19 +87,16 @@ def relate_multisegment(multipolygon: Multipolygon,
                                              multipolygon_max_x))
 
 
-def relate_contour(multipolygon: Multipolygon, contour: Contour,
-                   *,
+def relate_contour(multipolygon: Multipolygon,
+                   contour: Contour,
                    context: Context) -> Relation:
     if not multipolygon.polygons:
         return Relation.DISJOINT
-    contour_bounding_box = box.from_contour(contour,
-                                            context=context)
+    contour_bounding_box = box.from_contour(contour, context)
     disjoint, multipolygon_max_x, events_queue = True, None, None
     for polygon in multipolygon.polygons:
-        polygon_bounding_box = box.from_polygon(polygon,
-                                                context=context)
-        if not box.disjoint_with(polygon_bounding_box,
-                                 contour_bounding_box):
+        polygon_bounding_box = box.from_polygon(polygon, context)
+        if not box.disjoint_with(polygon_bounding_box, contour_bounding_box):
             if disjoint:
                 disjoint = False
                 multipolygon_max_x = polygon_bounding_box.max_x
@@ -113,10 +106,9 @@ def relate_contour(multipolygon: Multipolygon, contour: Contour,
             else:
                 multipolygon_max_x = max(multipolygon_max_x,
                                          polygon_bounding_box.max_x)
-            events_queue.register(
-                    polygon_to_oriented_segments(polygon,
-                                                 context=context),
-                    from_test=False)
+            events_queue.register(polygon_to_oriented_segments(polygon,
+                                                               context),
+                                  from_test=False)
     if disjoint:
         return Relation.DISJOINT
     return process_linear_compound_queue(events_queue,
@@ -124,20 +116,17 @@ def relate_contour(multipolygon: Multipolygon, contour: Contour,
                                              multipolygon_max_x))
 
 
-def relate_region(multipolygon: Multipolygon, region: Region,
-                  *,
+def relate_region(multipolygon: Multipolygon,
+                  region: Region,
                   context: Context) -> Relation:
     if not multipolygon.polygons:
         return Relation.DISJOINT
-    region_bounding_box = box.from_contour(region,
-                                           context=context)
+    region_bounding_box = box.from_contour(region, context)
     all_disjoint, none_disjoint, multipolygon_max_x, events_queue = (
         True, True, None, None)
     for polygon in multipolygon.polygons:
-        polygon_bounding_box = box.from_polygon(polygon,
-                                                context=context)
-        if box.disjoint_with(region_bounding_box,
-                             polygon_bounding_box):
+        polygon_bounding_box = box.from_polygon(polygon, context)
+        if box.disjoint_with(region_bounding_box, polygon_bounding_box):
             if none_disjoint:
                 none_disjoint = False
         else:
@@ -145,17 +134,15 @@ def relate_region(multipolygon: Multipolygon, region: Region,
                 all_disjoint = False
                 multipolygon_max_x = polygon_bounding_box.max_x
                 events_queue = CompoundEventsQueue(context)
-                events_queue.register(
-                        region_to_oriented_segments(region,
-                                                    context=context),
-                        from_test=True)
+                events_queue.register(region_to_oriented_segments(region,
+                                                                  context),
+                                      from_test=True)
             else:
                 multipolygon_max_x = max(multipolygon_max_x,
                                          polygon_bounding_box.max_x)
-            events_queue.register(
-                    polygon_to_oriented_segments(polygon,
-                                                 context=context),
-                    from_test=False)
+            events_queue.register(polygon_to_oriented_segments(polygon,
+                                                               context),
+                                  from_test=False)
     if all_disjoint:
         return Relation.DISJOINT
     relation = process_compound_queue(events_queue,
@@ -174,43 +161,36 @@ def relate_region(multipolygon: Multipolygon, region: Region,
 
 def relate_multiregion(multipolygon: Multipolygon,
                        multiregion: Multiregion,
-                       *,
                        context: Context) -> Relation:
     if not (multipolygon.polygons and multiregion):
         return Relation.DISJOINT
-    multiregion_bounding_box = box.from_contours(multiregion,
-                                                 context=context)
-    multipolygon_bounding_box = box.from_multipolygon(multipolygon,
-                                                      context=context)
-    if box.disjoint_with(multipolygon_bounding_box,
-                         multiregion_bounding_box):
+    multiregion_bounding_box = box.from_contours(multiregion, context)
+    multipolygon_bounding_box = box.from_multipolygon(multipolygon, context)
+    if box.disjoint_with(multipolygon_bounding_box, multiregion_bounding_box):
         return Relation.DISJOINT
     events_queue = CompoundEventsQueue(context)
-    events_queue.register(to_oriented_segments(multipolygon,
-                                               context=context),
+    events_queue.register(to_oriented_segments(multipolygon, context),
                           from_test=False)
     events_queue.register(multiregion_to_oriented_segments(multiregion,
-                                                           context=context),
+                                                           context),
                           from_test=True)
     return process_compound_queue(events_queue,
                                   min(multipolygon_bounding_box.max_x,
                                       multiregion_bounding_box.max_x))
 
 
-def relate_polygon(multipolygon: Multipolygon, polygon: Polygon,
-                   *,
+def relate_polygon(multipolygon: Multipolygon,
+                   polygon: Polygon,
                    context: Context) -> Relation:
     if not multipolygon.polygons:
         return Relation.DISJOINT
-    polygon_bounding_box = box.from_polygon(polygon,
-                                            context=context)
+    polygon_bounding_box = box.from_polygon(polygon, context)
     all_disjoint, none_disjoint, multipolygon_max_x, events_queue = (
         True, True, None, None)
     for sub_polygon in multipolygon.polygons:
         sub_polygon_bounding_box = box.from_contour(sub_polygon.border,
-                                                    context=context)
-        if box.disjoint_with(sub_polygon_bounding_box,
-                             polygon_bounding_box):
+                                                    context)
+        if box.disjoint_with(sub_polygon_bounding_box, polygon_bounding_box):
             if none_disjoint:
                 none_disjoint = False
         else:
@@ -218,17 +198,15 @@ def relate_polygon(multipolygon: Multipolygon, polygon: Polygon,
                 all_disjoint = False
                 multipolygon_max_x = sub_polygon_bounding_box.max_x
                 events_queue = CompoundEventsQueue(context)
-                events_queue.register(
-                        polygon_to_oriented_segments(polygon,
-                                                     context=context),
-                        from_test=True)
+                events_queue.register(polygon_to_oriented_segments(polygon,
+                                                                   context),
+                                      from_test=True)
             else:
                 multipolygon_max_x = max(multipolygon_max_x,
                                          sub_polygon_bounding_box.max_x)
-            events_queue.register(
-                    polygon_to_oriented_segments(sub_polygon,
-                                                 context=context),
-                    from_test=False)
+            events_queue.register(polygon_to_oriented_segments(sub_polygon,
+                                                               context),
+                                  from_test=False)
     if all_disjoint:
         return Relation.DISJOINT
     relation = process_compound_queue(events_queue,
@@ -245,21 +223,17 @@ def relate_polygon(multipolygon: Multipolygon, polygon: Polygon,
                         else relation)))
 
 
-def relate_multipolygon(goal: Multipolygon, test: Multipolygon,
-                        *,
+def relate_multipolygon(goal: Multipolygon,
+                        test: Multipolygon,
                         context: Context) -> Relation:
     if not (goal.polygons and test.polygons):
         return Relation.DISJOINT
-    goal_bounding_box = box.from_multipolygon(goal,
-                                              context=context)
-    test_bounding_box = box.from_multipolygon(test,
-                                              context=context)
+    goal_bounding_box = box.from_multipolygon(goal, context)
+    test_bounding_box = box.from_multipolygon(test, context)
     events_queue = CompoundEventsQueue(context)
-    events_queue.register(to_oriented_segments(goal,
-                                               context=context),
+    events_queue.register(to_oriented_segments(goal, context),
                           from_test=False)
-    events_queue.register(to_oriented_segments(test,
-                                               context=context),
+    events_queue.register(to_oriented_segments(test, context),
                           from_test=True)
     return process_compound_queue(events_queue,
                                   min(goal_bounding_box.max_x,
@@ -267,10 +241,8 @@ def relate_multipolygon(goal: Multipolygon, test: Multipolygon,
 
 
 def to_oriented_segments(multipolygon: Multipolygon,
-                         *,
-                         clockwise: bool = False,
-                         context: Context) -> Iterable[SegmentEndpoints]:
+                         context: Context,
+                         clockwise: bool = False
+                         ) -> Iterable[SegmentEndpoints]:
     for polygon in multipolygon.polygons:
-        yield from polygon_to_oriented_segments(polygon,
-                                                clockwise=clockwise,
-                                                context=context)
+        yield from polygon_to_oriented_segments(polygon, context, clockwise)
